@@ -3,7 +3,6 @@ package yqlib
 import (
 	"io"
 	"os"
-	"path/filepath"
 )
 
 func safelyRenameFile(from string, to string) {
@@ -26,7 +25,10 @@ func safelyRenameFile(from string, to string) {
 
 // thanks https://stackoverflow.com/questions/21060945/simple-way-to-copy-a-file-in-golang
 func copyFileContents(src, dst string) (err error) {
-	in, err := os.Open(filepath.Clean(src))
+	// ignore CWE-22 gosec issue - that's more targetted for http based apps that run in a public directory,
+	// and ensuring that it's not possible to give a path to a file outside thar directory.
+
+	in, err := os.Open(src) // #nosec
 	if err != nil {
 		return err
 	}
