@@ -9,13 +9,28 @@ import (
 	yaml "gopkg.in/yaml.v3"
 )
 
-func readStream(filename string) (io.Reader, error) {
+func readStream(filename string) (io.Reader, bool, error) {
+
 	if filename == "-" {
-		return bufio.NewReader(os.Stdin), nil
+		reader := bufio.NewReader(os.Stdin)
+
+		seperatorBytes, err := reader.Peek(3)
+		return reader, string(seperatorBytes) == "---", err
 	} else {
 		// ignore CWE-22 gosec issue - that's more targetted for http based apps that run in a public directory,
 		// and ensuring that it's not possible to give a path to a file outside thar directory.
-		return os.Open(filename) // #nosec
+		reader, err := os.Open(filename) // #nosec
+		if err != nil {
+			return nil, false, err
+		}
+		seperatorBytes := make([]byte, 3)
+		_, err = reader.Read(seperatorBytes)
+		if err != nil {
+			return nil, false, err
+		}
+		_, err = reader.Seek(0, 0)
+
+		return reader, string(seperatorBytes) == "---", err
 	}
 }
 
